@@ -32,9 +32,34 @@ DEFAULT_TIMEOUT = 5.0
 
 class WebScraperError(Exception):
     '''
-    Web scaper class.
+    Web scraper error class.
     '''
-    pass
+    def __init__(self, message, original=None):
+        super(WebScraperError, self).__init__(message)
+        self.original = original
+
+
+def webscraper_safely(call, *args, **kwargs):
+    '''
+    Wrapper to handle errors in HTTP requests.
+    '''
+    try:
+        return call(*args, **kwargs)
+    except urllib2.URLError as exc:
+        for attrname in ('reason', 'msg', 'message'):
+            value = getattr(exc, attrname, '')
+            if value:
+                raise WebScraperError('URL error: {0!s}'.format(value), exc)
+        raise WebScraperError('Unknown URL error: {0!s}'.format(exc), exc)
+    except httplib.HTTPException as exc:
+        raise WebScraperError(
+            'HTTP error {0!s}: {1!s}'.format(type(exc).__name__, exc),
+            exc
+        )
+    except socket.error as exc:
+        raise WebScraperError('Socket error: {0!s}'.format(exc), exc)
+    except IOError as exc:
+        raise WebScraperError('IO error: {0!s}'.format(exc), exc)
 
 
 class TimeoutRequest(mechanize.Request):
@@ -64,6 +89,7 @@ class WebScraper(object):
 
         # Cookie storage
         self.cookiejar = cookielib.CookieJar()
+        self.cookie_set = False
 
         # Browser instance
         self.browser = mechanize.Browser(
@@ -92,26 +118,6 @@ class WebScraper(object):
         if useragent is not None:
             self.browser.addheaders = [('User-agent', useragent)]
 
-    def _safely(self, call, *args, **kwargs):
-        '''
-        Wrapper to handle errors in HTTP requests.
-        '''
-        try:
-            return call(*args, **kwargs)
-        except urllib2.URLError as exc:
-            for attrname in ('reason', 'msg', 'message'):
-                value = getattr(exc, attrname, '')
-                if value:
-                    raise WebScraperError(value)
-                raise WebScraperError(str(exc))
-            raise WebScraperError('Unknown url error (%s)' % str(exc))
-        except httplib.BadStatusLine as exc:
-            raise WebScraperError('Bad status line (%s)' % str(exc))
-        except socket.error as exc:
-            raise WebScraperError('Socket error: %s' % str(exc))
-        except IOError as exc:
-            raise WebScraperError('IO error: %s' % str(exc))
-
     def _get_req_url(self, action):
         '''
         Formats request URL based on action.
@@ -129,16 +135,16 @@ class WebScraper(object):
             params = None
         else:
             params = urllib.urlencode(kwargs)
-        return self._safely(
+        return webscraper_safely(
             self.browser.open,
             url, params, timeout=DEFAULT_TIMEOUT
         )
 
-    def _submit(self):
+    def submit(self):
         '''
         Submits currently selected browser form.
         '''
-        return self._safely(
+        return webscraper_safely(
             self.browser.submit,
             request_class=TimeoutRequest
         )
@@ -149,6 +155,7 @@ class WebScraper(object):
         '''
         for cookie in cookies:
             self.cookiejar.set_cookie(cookie)
+        self.cookie_set = True
 
     def get_cookies(self):
         '''
